@@ -62,36 +62,31 @@ class BaseNEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
     -------
     >>> from category_encoders import *
     >>> import pandas as pd
-    >>> from sklearn.datasets import load_boston
-    >>> bunch = load_boston()
+    >>> from sklearn.datasets import fetch_openml
+    >>> bunch = fetch_openml(name="house_prices", as_frame=True)
+    >>> display_cols = ["Id", "MSSubClass", "MSZoning", "LotFrontage", "YearBuilt", "Heating", "CentralAir"]
     >>> y = bunch.target
-    >>> X = pd.DataFrame(bunch.data, columns=bunch.feature_names)
-    >>> enc = BaseNEncoder(cols=['CHAS', 'RAD']).fit(X, y)
+    >>> X = pd.DataFrame(bunch.data, columns=bunch.feature_names)[display_cols]
+    >>> enc = BaseNEncoder(cols=['CentralAir', 'Heating']).fit(X, y)
     >>> numeric_dataset = enc.transform(X)
     >>> print(numeric_dataset.info())
     <class 'pandas.core.frame.DataFrame'>
-    RangeIndex: 506 entries, 0 to 505
-    Data columns (total 18 columns):
-    CRIM       506 non-null float64
-    ZN         506 non-null float64
-    INDUS      506 non-null float64
-    CHAS_0     506 non-null int64
-    CHAS_1     506 non-null int64
-    NOX        506 non-null float64
-    RM         506 non-null float64
-    AGE        506 non-null float64
-    DIS        506 non-null float64
-    RAD_0      506 non-null int64
-    RAD_1      506 non-null int64
-    RAD_2      506 non-null int64
-    RAD_3      506 non-null int64
-    RAD_4      506 non-null int64
-    TAX        506 non-null float64
-    PTRATIO    506 non-null float64
-    B          506 non-null float64
-    LSTAT      506 non-null float64
-    dtypes: float64(11), int64(7)
-    memory usage: 71.3 KB
+    RangeIndex: 1460 entries, 0 to 1459
+    Data columns (total 10 columns):
+     #   Column        Non-Null Count  Dtype  
+    ---  ------        --------------  -----  
+     0   Id            1460 non-null   float64
+     1   MSSubClass    1460 non-null   float64
+     2   MSZoning      1460 non-null   object 
+     3   LotFrontage   1201 non-null   float64
+     4   YearBuilt     1460 non-null   float64
+     5   Heating_0     1460 non-null   int64  
+     6   Heating_1     1460 non-null   int64  
+     7   Heating_2     1460 non-null   int64  
+     8   CentralAir_0  1460 non-null   int64  
+     9   CentralAir_1  1460 non-null   int64  
+    dtypes: float64(4), int64(5), object(1)
+    memory usage: 114.2+ KB
     None
 
     """
@@ -180,7 +175,7 @@ class BaseNEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
             raise ValueError('Must train encoder before it can be used to inverse_transform data')
 
         # unite the type into pandas dataframe (it makes the input size detection code easier...) and make deep copy
-        X = util.convert_input(X_in, columns=self.feature_names, deep=True)
+        X = util.convert_input(X_in, columns=self.feature_names_out_, deep=True)
 
         X = self.basen_to_integer(X, self.cols, self.base)
 
@@ -271,7 +266,7 @@ class BaseNEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
         out_cols = X.columns.values.tolist()
 
         for col in cols:
-            col_list = [col0 for col0 in out_cols if re.match(str(col)+'_\\d+', str(col0))]
+            col_list = [col0 for col0 in out_cols if re.match(re.escape(str(col))+'_\\d+', str(col0))]
             insert_at = out_cols.index(col_list[0])
 
             if base == 1:
