@@ -45,42 +45,36 @@ class OneHotEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
     -------
     >>> from category_encoders import *
     >>> import pandas as pd
-    >>> from sklearn.datasets import load_boston
-    >>> bunch = load_boston()
+    >>> from sklearn.datasets import fetch_openml
+    >>> bunch = fetch_openml(name="house_prices", as_frame=True)
+    >>> display_cols = ["Id", "MSSubClass", "MSZoning", "LotFrontage", "YearBuilt", "Heating", "CentralAir"]
     >>> y = bunch.target
-    >>> X = pd.DataFrame(bunch.data, columns=bunch.feature_names)
-    >>> enc = OneHotEncoder(cols=['CHAS', 'RAD'], handle_unknown='indicator').fit(X, y)
+    >>> X = pd.DataFrame(bunch.data, columns=bunch.feature_names)[display_cols]
+    >>> enc = OneHotEncoder(cols=['CentralAir', 'Heating'], handle_unknown='indicator').fit(X, y)
     >>> numeric_dataset = enc.transform(X)
     >>> print(numeric_dataset.info())
     <class 'pandas.core.frame.DataFrame'>
-    RangeIndex: 506 entries, 0 to 505
-    Data columns (total 24 columns):
-    CRIM       506 non-null float64
-    ZN         506 non-null float64
-    INDUS      506 non-null float64
-    CHAS_1     506 non-null int64
-    CHAS_2     506 non-null int64
-    CHAS_-1    506 non-null int64
-    NOX        506 non-null float64
-    RM         506 non-null float64
-    AGE        506 non-null float64
-    DIS        506 non-null float64
-    RAD_1      506 non-null int64
-    RAD_2      506 non-null int64
-    RAD_3      506 non-null int64
-    RAD_4      506 non-null int64
-    RAD_5      506 non-null int64
-    RAD_6      506 non-null int64
-    RAD_7      506 non-null int64
-    RAD_8      506 non-null int64
-    RAD_9      506 non-null int64
-    RAD_-1     506 non-null int64
-    TAX        506 non-null float64
-    PTRATIO    506 non-null float64
-    B          506 non-null float64
-    LSTAT      506 non-null float64
-    dtypes: float64(11), int64(13)
-    memory usage: 95.0 KB
+    RangeIndex: 1460 entries, 0 to 1459
+    Data columns (total 15 columns):
+     #   Column         Non-Null Count  Dtype  
+    ---  ------         --------------  -----  
+     0   Id             1460 non-null   float64
+     1   MSSubClass     1460 non-null   float64
+     2   MSZoning       1460 non-null   object 
+     3   LotFrontage    1201 non-null   float64
+     4   YearBuilt      1460 non-null   float64
+     5   Heating_1      1460 non-null   int64  
+     6   Heating_2      1460 non-null   int64  
+     7   Heating_3      1460 non-null   int64  
+     8   Heating_4      1460 non-null   int64  
+     9   Heating_5      1460 non-null   int64  
+     10  Heating_6      1460 non-null   int64  
+     11  Heating_-1     1460 non-null   int64  
+     12  CentralAir_1   1460 non-null   int64  
+     13  CentralAir_2   1460 non-null   int64  
+     14  CentralAir_-1  1460 non-null   int64  
+    dtypes: float64(4), int64(10), object(1)
+    memory usage: 171.2+ KB
     None
 
     References
@@ -142,7 +136,7 @@ class OneHotEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
             new_columns = []
 
             append_nan_to_index = False
-            for cat_name, class_ in values.iteritems():
+            for cat_name, class_ in values.items():
                 if pd.isna(cat_name) and self.handle_missing == 'return_nan':
                     # we don't want a mapping column if return_nan
                     # but do add the index to the end
@@ -217,7 +211,7 @@ class OneHotEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
             raise ValueError('Must train encoder before it can be used to inverse_transform data')
 
         # first check the type and make deep copy
-        X = util.convert_input(X_in, columns=self.feature_names, deep=True)
+        X = util.convert_input(X_in, columns=self.feature_names_out_, deep=True)
 
         X = self.reverse_dummies(X, self.mapping)
 
