@@ -4,6 +4,7 @@ import numpy as np
 import pandas as pd
 import category_encoders.utils as util
 import warnings
+from typing import Dict, List, Union
 
 __author__ = 'willmcginnis'
 
@@ -30,7 +31,7 @@ class OrdinalEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
         a mapping of class to label to use for the encoding, optional.
         the dict contains the keys 'col' and 'mapping'.
         the value of 'col' should be the feature name.
-        the value of 'mapping' should be a dictionary of 'original_label' to 'encoded_label'.
+        the value of 'mapping' should be a dictionary or pd.Series of 'original_label' to 'encoded_label'.
         example mapping: [
             {'col': 'col1', 'mapping': {None: 0, 'a': 1, 'b': 2}},
             {'col': 'col2', 'mapping': {None: 0, 'x': 1, 'y': 2}}
@@ -45,31 +46,28 @@ class OrdinalEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
     -------
     >>> from category_encoders import *
     >>> import pandas as pd
-    >>> from sklearn.datasets import load_boston
-    >>> bunch = load_boston()
+    >>> from sklearn.datasets import fetch_openml
+    >>> bunch = fetch_openml(name="house_prices", as_frame=True)
+    >>> display_cols = ["Id", "MSSubClass", "MSZoning", "LotFrontage", "YearBuilt", "Heating", "CentralAir"]
     >>> y = bunch.target
-    >>> X = pd.DataFrame(bunch.data, columns=bunch.feature_names)
-    >>> enc = OrdinalEncoder(cols=['CHAS', 'RAD']).fit(X, y)
+    >>> X = pd.DataFrame(bunch.data, columns=bunch.feature_names)[display_cols]
+    >>> enc = OrdinalEncoder(cols=['CentralAir', 'Heating']).fit(X, y)
     >>> numeric_dataset = enc.transform(X)
     >>> print(numeric_dataset.info())
     <class 'pandas.core.frame.DataFrame'>
-    RangeIndex: 506 entries, 0 to 505
-    Data columns (total 13 columns):
-    CRIM       506 non-null float64
-    ZN         506 non-null float64
-    INDUS      506 non-null float64
-    CHAS       506 non-null int64
-    NOX        506 non-null float64
-    RM         506 non-null float64
-    AGE        506 non-null float64
-    DIS        506 non-null float64
-    RAD        506 non-null int64
-    TAX        506 non-null float64
-    PTRATIO    506 non-null float64
-    B          506 non-null float64
-    LSTAT      506 non-null float64
-    dtypes: float64(11), int64(2)
-    memory usage: 51.5 KB
+    RangeIndex: 1460 entries, 0 to 1459
+    Data columns (total 7 columns):
+     #   Column       Non-Null Count  Dtype  
+    ---  ------       --------------  -----  
+     0   Id           1460 non-null   float64
+     1   MSSubClass   1460 non-null   float64
+     2   MSZoning     1460 non-null   object 
+     3   LotFrontage  1201 non-null   float64
+     4   YearBuilt    1460 non-null   float64
+     5   Heating      1460 non-null   int64  
+     6   CentralAir   1460 non-null   int64  
+    dtypes: float64(4), int64(2), object(1)
+    memory usage: 80.0+ KB
     None
 
     References
@@ -90,6 +88,8 @@ class OrdinalEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
         super().__init__(verbose=verbose, cols=cols, drop_invariant=drop_invariant, return_df=return_df,
                          handle_unknown=handle_unknown, handle_missing=handle_missing)
         self.mapping_supplied = mapping is not None
+        if self.mapping_supplied:
+            mapping = self._validate_supplied_mapping(mapping)
         self.mapping = mapping
 
     @property
@@ -219,9 +219,7 @@ class OrdinalEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
         else:
             mapping_out = []
             for col in cols:
-
                 nan_identity = np.nan
-                
                 categories = list(X[col].unique())
                 if util.is_category(X[col].dtype):
                     # Avoid using pandas category dtype meta-data if possible, see #235, #238.
@@ -242,3 +240,28 @@ class OrdinalEncoder(util.BaseEncoder, util.UnsupervisedTransformerMixin):
                 mapping_out.append({'col': col, 'mapping': data, 'data_type': X[col].dtype}, )
 
         return X, mapping_out
+
+    def _validate_supplied_mapping(self, supplied_mapping: List[Dict[str, Union[str, Dict, pd.Series]]]) -> List[Dict[str, Union[str, pd.Series]]]:
+        """
+        validate the supplied mapping and convert the actual mapping per column to a pandas series.
+        :param supplied_mapping: mapping as list of dicts. They actual mapping can be either a dict or pd.Series
+        :return: the mapping with all actual mappings being pandas series
+        """
+        msg = "Invalid supplied mapping, must be of type List[Dict[str, Union[Dict, pd.Series]]]." \
+              "For an example refer to the documentation"
+        if not isinstance(supplied_mapping, list):
+            raise ValueError(msg)
+        for mapping_el in supplied_mapping:
+            if not isinstance(mapping_el, dict):
+                raise ValueError(msg)
+            if "col" not in mapping_el:
+                raise KeyError("Mapping must contain a key 'col' for each column to encode")
+            if "mapping" not in mapping_el:
+                raise KeyError("Mapping must contain a key 'mapping' for each column to encode")
+            mapping = mapping_el["mapping"]
+            if isinstance(mapping_el, dict):
+                # convert to dict in order to standardise
+                mapping_el["mapping"] = pd.Series(mapping)
+            if "data_type" not in mapping_el:
+                mapping_el["data_type"] = mapping_el["mapping"].index.dtype
+        return supplied_mapping
