@@ -35,39 +35,33 @@ class PolynomialEncoder(BaseContrastEncoder):
     -------
     >>> from category_encoders import *
     >>> import pandas as pd
-    >>> from sklearn.datasets import load_boston
-    >>> bunch = load_boston()
+    >>> from sklearn.datasets import fetch_openml
+    >>> bunch = fetch_openml(name="house_prices", as_frame=True)
+    >>> display_cols = ["Id", "MSSubClass", "MSZoning", "LotFrontage", "YearBuilt", "Heating", "CentralAir"]
     >>> y = bunch.target
-    >>> X = pd.DataFrame(bunch.data, columns=bunch.feature_names)
-    >>> enc = PolynomialEncoder(cols=['CHAS', 'RAD']).fit(X, y)
+    >>> X = pd.DataFrame(bunch.data, columns=bunch.feature_names)[display_cols]
+    >>> enc = PolynomialEncoder(cols=['CentralAir', 'Heating']).fit(X, y)
     >>> numeric_dataset = enc.transform(X)
     >>> print(numeric_dataset.info())
     <class 'pandas.core.frame.DataFrame'>
-    RangeIndex: 506 entries, 0 to 505
-    Data columns (total 21 columns):
-    intercept    506 non-null int64
-    CRIM         506 non-null float64
-    ZN           506 non-null float64
-    INDUS        506 non-null float64
-    CHAS_0       506 non-null float64
-    NOX          506 non-null float64
-    RM           506 non-null float64
-    AGE          506 non-null float64
-    DIS          506 non-null float64
-    RAD_0        506 non-null float64
-    RAD_1        506 non-null float64
-    RAD_2        506 non-null float64
-    RAD_3        506 non-null float64
-    RAD_4        506 non-null float64
-    RAD_5        506 non-null float64
-    RAD_6        506 non-null float64
-    RAD_7        506 non-null float64
-    TAX          506 non-null float64
-    PTRATIO      506 non-null float64
-    B            506 non-null float64
-    LSTAT        506 non-null float64
-    dtypes: float64(20), int64(1)
-    memory usage: 83.1 KB
+    RangeIndex: 1460 entries, 0 to 1459
+    Data columns (total 12 columns):
+     #   Column        Non-Null Count  Dtype  
+    ---  ------        --------------  -----  
+     0   intercept     1460 non-null   int64  
+     1   Id            1460 non-null   float64
+     2   MSSubClass    1460 non-null   float64
+     3   MSZoning      1460 non-null   object 
+     4   LotFrontage   1201 non-null   float64
+     5   YearBuilt     1460 non-null   float64
+     6   Heating_0     1460 non-null   float64
+     7   Heating_1     1460 non-null   float64
+     8   Heating_2     1460 non-null   float64
+     9   Heating_3     1460 non-null   float64
+     10  Heating_4     1460 non-null   float64
+     11  CentralAir_0  1460 non-null   float64
+    dtypes: float64(10), int64(1), object(1)
+    memory usage: 137.0+ KB
     None
 
     References
